# OnShapepy [![Build Status](https://travis-ci.org/AguaClara/onshapepy.svg?branch=master)](https://travis-ci.org/AguaClara/onshapepy) [![codecov](https://codecov.io/gh/AguaClara/onshapepy/branch/master/graph/badge.svg)](https://codecov.io/gh/AguaClara/onshapepy)

Access OnShape part configurations from your python interpreter! Allows you to use Numpy, Scipy, and any other python packages you may need to accurately configure your part. An open source alternative to CADWolf or SwiftCalcs.

## [Documentation is here!](https://aguaclara.github.io/onshapepy/)
